module.exports = defineTest({
	description: 'properly handles exporting async functions'
});
